! recalculate vegetation cover and LAI
!
! $Header: /home/ssipsl/CVSREP/ORCHIDEE/src_stomate/lpj_cover.f90,v 1.3 2002/09/24 21:12:16 ssipsl Exp $
!
MODULE lpj_cover

  ! modules used:

  USE ioipsl
  USE stomate_constants

  IMPLICIT NONE

  ! private & public routines

  PRIVATE
  PUBLIC cover

CONTAINS

  SUBROUTINE cover (npts, cn_ind, ind, biomass, &
                    veget_max, veget, lai)

    !
    ! 0 declarations
    !

    ! 0.1 input

    ! Domain size
    INTEGER, INTENT(in)                                   :: npts
    ! crown area (m**2) per ind.
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)          :: cn_ind
    ! density of individuals (1/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)          :: ind
    ! biomass (gC/(m**2 of nat/agri ground))
    REAL(stnd), DIMENSION(npts,npft,nparts), INTENT(in)   :: biomass

    ! 0.2 modified fields

    ! "maximal" coverage fraction of a PFT (LAI -> infinity) on nat/agri ground
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)       :: veget_max

    ! 0.3 output

    ! fractional coverage on natural/agricultural ground, taking into
    !   account LAI (=grid-scale fpc)
    REAL(stnd), DIMENSION(npts,npft), INTENT(inout)       :: veget
    ! leaf area index OF AN INDIVIDUAL PLANT
    REAL(stnd), DIMENSION(npts,npft), INTENT(in)         :: lai

    ! 0.4 local

    ! index
    INTEGER(long)                                         :: j

    ! =========================================================================

    !
    ! 1 If the vegetation is dynamic, calculate new maximum vegetation cover for
    !   natural plants
    !

    IF ( control%ok_dgvm ) THEN

      DO j = 1, npft

        IF ( natural(j) ) THEN

          veget_max(:,j) = ind(:,j) * cn_ind(:,j)

        ENDIF

      ENDDO

    ENDIF

    !
    ! 2 Calculate LAI
    !   The LAI is defined on the space covered by the crown of the plant.
    !    ( biomass / veget_max ) is in gC/(m**2 covered by the crown)
    !


    !
    ! 3 calculate grid-scale fpc (foliage protected cover)
    !

    DO j = 1, npft
      veget(:,j) = veget_max(:,j) * ( 1. - exp( - lai(:,j) * ext_coeff(j) ) )
    ENDDO

  END SUBROUTINE cover

END MODULE lpj_cover
